export declare type RangeMapper = (fromByte: number, toByte: number) => {
    url: string;
    fromByte: number;
    toByte: number;
};
export declare type LazyFileConfig = {
    /** function to map a read request to an url with read request  */
    rangeMapper: RangeMapper;
    /** must be known beforehand if there's multiple server chunks (i.e. rangeMapper returns different urls) */
    fileLength?: number;
    requestChunkSize: number;
    /** number of virtual read heads. default: 3 */
    maxReadHeads?: number;
    /** max read speed for sequential access. default: 5 MiB */
    maxReadSpeed?: number;
    logPageReads?: boolean;
};
export declare type PageReadLog = {
    pageno: number;
    wasCached: boolean;
    prefetch: number;
};
export declare class LazyUint8Array {
    private serverChecked;
    private readonly chunks;
    totalFetchedBytes: number;
    totalRequests: number;
    readPages: PageReadLog[];
    private _length?;
    private readonly readHeads;
    private readonly _chunkSize;
    private readonly rangeMapper;
    private readonly maxSpeed;
    private readonly maxReadHeads;
    private readonly logPageReads;
    constructor(config: LazyFileConfig);
    copyInto(buffer: Uint8Array, outOffset: number, _length: number, start: number): number;
    get(idx: number): number | undefined;
    lastGet: number;
    private moveReadHead;
    private getChunk;
    checkServer(): void;
    get length(): number;
    get chunkSize(): number;
    private doXHR;
}
export declare function createLazyFile(FS: any, parent: string, name: string, canRead: boolean, canWrite: boolean, lazyFileConfig: LazyFileConfig): any;
